@@ -1,5 +1,5 @@
 package App::gimpgitbuild::Command::build;
-$App::gimpgitbuild::Command::build::VERSION = '0.6.1';
+$App::gimpgitbuild::Command::build::VERSION = '0.8.0';
 use strict;
 use warnings;
 use 5.014;
@@ -48,6 +48,17 @@ sub _check
 sub _git_build
 {
     my $args = shift;
+    my $id   = $args->{id};
+
+    my $KEY = "GIMPGITBUILD__SKIP_BUILDS_RE";
+    if ( exists $ENV{$KEY} )
+    {
+        my $re = $ENV{$KEY};
+        if ( $id =~ /$re/ )
+        {
+            return;
+        }
+    }
     $args->{branch} //= 'master';
     $args->{tag}    //= 'false';
 
@@ -101,6 +112,7 @@ sub execute
     my $GNOME_GIT = 'https://gitlab.gnome.org/GNOME';
     _git_build(
         {
+            id        => "babl",
             git_co    => "$base_src_dir/babl/git/babl",
             url       => "$GNOME_GIT/babl",
             prefix    => "$babl_p",
@@ -109,6 +121,7 @@ sub execute
     );
     _git_build(
         {
+            id        => "gegl",
             git_co    => "$base_src_dir/gegl/git/gegl",
             url       => "$GNOME_GIT/gegl",
             prefix    => "$gegl_p",
@@ -117,6 +130,7 @@ sub execute
     );
     _git_build(
         {
+            id        => "libmypaint",
             git_co    => "$base_src_dir/libmypaint/git/libmypaint",
             url       => "https://github.com/mypaint/libmypaint.git",
             prefix    => "$mypaint_p",
@@ -127,6 +141,7 @@ sub execute
     );
     _git_build(
         {
+            id        => "mypaint-brushes",
             git_co    => "$base_src_dir/libmypaint/git/mypaint-brushes",
             url       => "https://github.com/Jehan/mypaint-brushes.git",
             prefix    => "$mypaint_p",
@@ -138,6 +153,7 @@ sub execute
 # autoconf_git_build "$base_src_dir/git/gimp" "$GNOME_GIT"/gimp "$HOME/apps/gimp-devel"
     _git_build(
         {
+            id        => "gimp",
             git_co    => "$base_src_dir/git/gimp",
             url       => "$GNOME_GIT/gimp",
             prefix    => $obj->gimp_p,
@@ -161,7 +177,7 @@ __END__
 
 =head1 VERSION
 
-version 0.6.1
+version 0.8.0
 
 =begin foo return (
         [ "output|o=s", "Output path" ],
